/******************************************************************************
* C Source: File Names                                                        *
*                                                                             *
* File:                                                                       *
*    filenams.c                                                               *
*                                                                             *
* Description:                                                                *
*    This set of functions are used to determine the attributes of the        *
*    filenames on the CD-ROM. The attributes determined are the case of the   *
*    the filename, trailing semi-colon, and trailing period for files with no *
*    extension. The attributes are determined by looking for various forms    *
*    of the copyright file. The forms searched for are:                       *
*                                                                             *
*         COPYRGHT.;     COPYRGHT.     COPYRGHT;     COPYRGHT                 *
*         copyrght.;     copyrght.     copyrght;     copyrght                 *
*                                                                             *
*   In addition, there are routines for generally building filenames.         *
*                                                                             *
* Module List:                                                                *
*    Build_Full_File_Name:                                                    *
*       Puts together directory, subdirectory and filename depending on the   *
*       operating system.                                                     *
*    Build_Full_UNIX_File_Name:                                               *
*       Puts together directory, subdirectory and filename for UNIX           *
*       operating system.                                                     *
*    Build_Full_VMS_File_Name:                                                *
*       Puts together directory, subdirectory and filename for OpenVMS        *
*       operating system.                                                     *
*    CopyRight_File_Exists                                                    *
*       Copyright file found in in given directory                            *
*    FileNames_in_LowerCase                                                   *
*       Returns TRUE if name of copyright file in given directory is lower    *
*       case, else it returns FALSE.                                          *
*    FileNames_in_UpperCase                                                   *
*       Returns TRUE if name of copyright file in given directory is upper    *
*       case, else it returns FALSE.                                          *
*    FileNames_have_Version                                                   *
*       Returns TRUE if name of copyright file in given directory has         *
*       a version number, ie a trailing semicolon followed by a 1.            *
*    FileNames_Trailing_Period                                                *
*       Returns TRUE if name of copyright file in given directory contains    *
*       contains a trailing period before the version. This indicates that    *
*       filenames without extensions keep the period separator.               *
*    Set_FileNames_Case                                                       *
*       Set the case of a filename according to the case of the copyright     *
*       file in given directory.                                              *
*    Set_FileNames_Version                                                    *
*       Add the version, semicolon followed by a 1, to a filename if the      *
*       copyright file in given directory has the version.                    *
*                                                                             *
* History:                                                                    *
*    Created    : 15-NOV-93 by J. Doggett,                                    *
*       for the Association of Universities for Research in Astronomy, Inc.   *
*          at the Space Telescope Science Institute,                          *
*       to facilitate the accessing of data from the CD-ROM set of the        *
*          Digitized Sky Survey.                                              *
*    Delivered  : 01-MAR-94 by J. Doggett,                                    *
*       GetImage Version 1.0                                                  *
*                                                                             *
* Copyright (c) 1993, 1994, Association of Universities for Research in       *
* Astronomy, Inc.  All Rights Reserved.                                       *
* Produced under National Aeronautics and Space Administration grant          *
* NAG W-2166.                                                                 *
******************************************************************************/
#include <stdio.h>

/*********************************
* File Names introduction page 2 *
*********************************/

#include <stdlib.h>
#include <string.h>

/* access function not prototyped in standard place */
#if defined __VMS
#  include <unixio.h>
#elif defined __UNIX
#  include <unixstd.h>
#else
#endif

#include "filenams.h"

#include "config.h"
#include "generic.h"

/******************************************************************************
* Module:                                                                     *
*    Build_Full_File_Name                                                     *
*                                                                             *
* File:                                                                       *
*    filenams.c                                                               *
*                                                                             *
* Description:                                                                *
*    Builds a full filename depending on the operating system given a         *
*    directory, subdirectory, and filename.                                   *
*                                                                             *
* Return Value:                                                               *
*    STRING: Resultant filename.                                              *
*                                                                             *
* Arguments;                                                                  *
*                                                                             *
*    Input Arguments:                                                         *
*       Directory                                                             *
*          STRING, Reference                                                  *
*             Directory above the given sub-directory where the file resides. *
*             If the sub-directory is empty, then it's the directory where    *
*             the file resides.                                               *
*       Sub_Directory                                                         *
*          STRING, Reference                                                  *
*             Sub-directory below directory where file resides.               *
*       File                                                                  *
*          STRING, Reference                                                  *
*             Name of the file.                                               *
*    Input/Output Arguments:                                                  *
*       none                                                                  *
*    Output Arguments:                                                        *
*       none                                                                  *
*                                                                             *
* History:                                                                    *
*    Created    : 24-AUG-93 by J. Doggett,                                    *
*       for the Association of Universities for Research in Astronomy, Inc.   *
*          at the Space Telescope Science Institute,                          *
*       to facilitate the accessing of data from the CD-ROM set of the        *
*          Digitized Sky Survey.                                              *
*    Delivered  : 01-MAR-94 by J. Doggett,                                    *
*       GetImage Version 1.0                                                  *
******************************************************************************/
/************************************
* Build_Full_File_Name declarations *
************************************/
STRING Build_Full_File_Name( Directory, Sub_Directory, File )
STRING Directory    ;
STRING Sub_Directory;
STRING File         ;
{
/*********************************************
* Build_Full_File_Name begin executable code *
*********************************************/
#if defined __VMS
   return Build_Full_VMS_File_Name( Directory, Sub_Directory, File );

#elif defined __UNIX
   return Build_Full_UNIX_File_Name( Directory, Sub_Directory, File );

#else
   fprintf(stderr, "Unknown file system error in Build_Full_FileName");
   exit(EXIT_FAILURE);

#endif

/******************************
* Build_Full_File_Name page 2 *
******************************/

}
/*******************************************
* Build_Full_File_Name end executable code *
*******************************************/

/******************************************************************************
* Module:                                                                     *
*    Build_Full_UNIX_File_Name                                                *
*                                                                             *
* File:                                                                       *
*    filenams.c                                                               *
*                                                                             *
* Description:                                                                *
*    Builds a full UNIX filename given a directory, subdirectory, and         *
*    filename.                                                                *
*                                                                             *
*    There are several cases to deal with:                                    *
*                                                                             *
*          Dir      SubDir     File     Result                                *
*          ---      ------     ----     ------                                *
*          a/         b/       file     a/b/file                              *
*          a/         b        file     a/b/file                              *
*          a/         ""       file     a/b/file                              *
*          a          b/       file     a/b/file                              *
*          a          b        file     a/b/file                              *
*          a          ""       file     a/b/file                              *
*          ""         b/       file     a/b/file                              *
*          ""         b        file     a/b/file                              *
*          ""         ""       file     a/b/file                              *
*                                                                             *
* Return Value:                                                               *
*    STRING: Resultant filename.                                              *
*                                                                             *
* Arguments;                                                                  *
*                                                                             *
*    Input Arguments:                                                         *
*       Directory                                                             *
*          STRING, Reference                                                  *
*             Directory above the given sub-directory where the file resides. *
*             If the sub-directory is empty, then it's the directory where    *
*             the file resides.                                               *
*       Sub_Directory                                                         *
*          STRING, Reference                                                  *
*             Sub-directory below directory where file resides.               *
*       File                                                                  *
*          STRING, Reference                                                  *
*             Name of the file.                                               *
*    Input/Output Arguments:                                                  *
*       none                                                                  *
*    Output Arguments:                                                        *
*       none                                                                  *
*                                                                             *
* History:                                                                    *
*    Created    : 24-AUG-93 by J. Doggett,                                    *
*       for the Association of Universities for Research in Astronomy, Inc.   *
*          at the Space Telescope Science Institute,                          *
*       to facilitate the accessing of data from the CD-ROM set of the        *
*          Digitized Sky Survey.                                              *
*    Delivered  : 01-MAR-94 by J. Doggett,                                    *
*       GetImage Version 1.0                                                  *
******************************************************************************/
/*****************************************
* Build_Full_UNIX_File_Name declarations *
*****************************************/
STRING Build_Full_UNIX_File_Name( Directory, Sub_Directory, File )
STRING Directory    ;
STRING Sub_Directory;
STRING File         ;
{

/***********************************
* Build_Full_UNIX_File_Name page 2 *
***********************************/
   int    Directory_Len    ; /* Length of input strings */
   int    Sub_Directory_Len;
   int    File_Len    ;

   STRING Full_File       ; /* Resultant full OpenVMS file name to return */
   int    Full_File_Len;

/**************************************************
* Build_Full_UNIX_File_Name begin executable code *
**************************************************/
   if ( Directory != NULL )
      Directory_Len = strlen( Directory );
   else
      Directory_Len = 0;

   if ( Sub_Directory != NULL )
      Sub_Directory_Len = strlen( Sub_Directory );
   else
      Sub_Directory_Len = 0;

   if ( File != NULL )
      File_Len = strlen( File );
   else
      File_Len = 0;

   Full_File_Len = Directory_Len + Sub_Directory_Len + File_Len;

   if ( Directory_Len > 0 )
   { /* We've got a directory */

      if ( Directory[ Directory_Len - 1 ] == '/' )
      { /* directory = a/ */

         if ( Sub_Directory_Len > 0 )
	 { /* a/ + sub_dir + file */

            if ( Sub_Directory[ Sub_Directory_Len - 1 ] == '/' )
   	    { /* a/ + b/ + file --> a/b/file */

               Full_File = ( STRING )Allocate_Memory( Full_File_Len + 1 );
               strcpy( Full_File, Directory );
               strcat( Full_File, Sub_Directory );
               if ( File_Len > 0 )
                  strcat( Full_File, File );
	    }
            else
	    { /* a/ + b + file --> a/b/file */

               Full_File_Len += 1;
               Full_File = ( STRING )Allocate_Memory( Full_File_Len + 1 );
               strcpy( Full_File, Directory );
               strcat( Full_File, Sub_Directory );
               strcat( Full_File, "/" );
               if ( File_Len > 0 )
                  strcat( Full_File, File );
	    }
	 }
	 else
	 { /* a/ + file --> a/file */

            Full_File = ( STRING )Allocate_Memory( Full_File_Len + 1 );

/***********************************
* Build_Full_UNIX_File_Name page 3 *
***********************************/

            strcpy( Full_File, Directory );
            if ( File_Len > 0 )
               strcat( Full_File, File );
	 }
      }
      else
      { /* directory = a */

         if ( Sub_Directory_Len > 0 )
	 { /* a + sub_dir + file */

            if ( Sub_Directory[ Sub_Directory_Len - 1 ] == '/' )
   	    { /* a + b/ + file --> a/b/file */

               Full_File_Len += 1;
               Full_File = ( STRING )Allocate_Memory( Full_File_Len + 1 );
               strcpy( Full_File, Directory );
               strcat( Full_File, "/" );
               strcat( Full_File, Sub_Directory );
               if ( File_Len > 0 )
                  strcat( Full_File, File );
	    }
            else
	    { /* a + b + file --> a/b/file */

               Full_File_Len += 2;
               Full_File = ( STRING )Allocate_Memory( Full_File_Len + 1 );
               strcpy( Full_File, Directory );
               strcat( Full_File, "/" );
               strcat( Full_File, Sub_Directory );
               strcat( Full_File, "/" );
               if ( File_Len > 0 )
                  strcat( Full_File, File );
	    }
	 }
	 else
	 { /* a + file --> a/file */
            Full_File_Len += 1;
            Full_File = ( STRING )Allocate_Memory( Full_File_Len + 1 );
            strcpy( Full_File, Directory );
            strcat( Full_File, "/" );
            if ( File_Len > 0 )
               strcat( Full_File, File );
	 }
      }
   } /* We've got a directory */
   else
   { /* We don't got a directory */

      if ( Sub_Directory_Len > 0 )
      { /* sub_dir + file */
         if ( Sub_Directory[ Sub_Directory_Len - 1 ] == '/' )
   	 { /*  b/ + file --> b/file */

            Full_File = ( STRING )Allocate_Memory( Full_File_Len + 1 );
            strcat( Full_File, Sub_Directory );
            if ( File_Len > 0 )
               strcat( Full_File, File );
         }
         else

/***********************************
* Build_Full_UNIX_File_Name page 4 *
***********************************/

	 { /* b + file --> a/b/file */
            Full_File_Len += 1;
            Full_File = ( STRING )Allocate_Memory( Full_File_Len + 1 );
            strcat( Full_File, Sub_Directory );
            strcat( Full_File, "/" );
            if ( File_Len > 0 )
               strcat( Full_File, File );
	 }
      }
      else
      { /* file --> file */
         Full_File = ( STRING )Allocate_Memory( Full_File_Len + 1 );
         if ( File_Len > 0 )
            strcpy( Full_File, File );
         else
            Full_File[ 0 ] = ( char )NULL;
      }

   } /* We don't got a directory */

   return Full_File;
}
/************************************************
* Build_Full_UNIX_File_Name end executable code *
************************************************/

/******************************************************************************
* Module:                                                                     *
*    Build_Full_VMS_File_Name                                                 *
*                                                                             *
* File:                                                                       *
*    filenams.c                                                               *
*                                                                             *
* Description:                                                                *
*    Builds a full OpenVMS filename (excepting the version number) given a    *
*    directory, subdirectory, and filename.                                   *
*                                                                             *
*    There are several cases to deal with:                                    *
*                                                                             *
*          Dir      SubDir     File     Result                                *
*          ---      ------     ----     ------                                *
*         [A.]        B        FILE     [A.B]FILE                             *
*         [A.]        ""       FILE     [A]FILE                               *
*         [A]         B        FILE     [A.B]FILE                             *
*         [A]         ""       FILE     [A]FILE                               *
*         A:          B        FILE     A:[B]FILE                             *
*         A:          ""       FILE     A:FILE                                *
*         A           B        FILE     A:[B]FILE                             *
*         A           ""       FILE     A:                                    *
*         ""          B        FILE     [.B]FILE                              *
*         ""          ""       FILE     FILE                                  *
*                                                                             *
* Return Value:                                                               *
*    STRING: Resultant filename.                                              *
*                                                                             *
* Arguments;                                                                  *
*                                                                             *
*    Input Arguments:                                                         *
*       Directory                                                             *
*          STRING, Reference                                                  *
*             Directory above the given sub-directory where the file resides  *
*             If the sub-directory is empty, then it's the directory where    *
*             the file resides.                                               *
*       Sub_Directory                                                         *
*          STRING, Reference                                                  *
*             Sub-directory below directory where file resides.               *
*       File                                                                  *
*          STRING, Reference                                                  *
*             Name of the file.                                               *
*    Input/Output Arguments:                                                  *
*       none                                                                  *
*    Output Arguments:                                                        *
*       none                                                                  *
*                                                                             *
* History:                                                                    *
*    Created    : 24-AUG-93 by J. Doggett,                                    *
*       for the Association of Universities for Research in Astronomy, Inc.   *
*          at the Space Telescope Science Institute,                          *
*       to facilitate the accessing of data from the CD-ROM set of the        *
*          Digitized Sky Survey.                                              *
*    Delivered  : 01-MAR-94 by J. Doggett,                                    *
*       GetImage Version 1.0                                                  *
******************************************************************************/
/****************************************
* Build_Full_VMS_File_Name declarations *
****************************************/
STRING Build_Full_VMS_File_Name( Directory, Sub_Directory, File )
STRING Directory    ;
STRING Sub_Directory;
STRING File         ;

/**********************************
* Build_Full_VMS_File_Name page 2 *
**********************************/

{
   int    Directory_Len    ; /* Length of input strings */
   int    Sub_Directory_Len;
   int    File_Len    ;

   STRING Full_File       ; /* Resultant full OpenVMS file name to return */
   int    Full_File_Len;

/*************************************************
* Build_Full_VMS_File_Name begin executable code *
*************************************************/
   if ( Directory != NULL )
      Directory_Len = strlen( Directory );
   else
      Directory_Len = 0;

   if ( Sub_Directory != NULL )
      Sub_Directory_Len = strlen( Sub_Directory );
   else
      Sub_Directory_Len = 0;

   if ( File != NULL )
      File_Len = strlen( File );
   else
      File_Len = 0;

   Full_File_Len = Directory_Len + Sub_Directory_Len + File_Len;

   if ( Directory_Len > 0 )
   { /* We've got a directory */
      switch ( Directory[ Directory_Len - 1 ] )
      { /* Process each case with a directory */
         case ']':
            if ( ( Directory_Len                  >  1   )
                                                     &&
                 ( Directory[ Directory_Len - 2 ] == '.' ) )
	    { /* Directory = [a.] */

               if ( Sub_Directory_Len > 0 )
	       { /* [a.] + b + file --> [a.b]file */

                  Full_File = ( STRING )Allocate_Memory( Full_File_Len + 1 );
                  strncpy( Full_File, Directory, Directory_Len - 1 );
                  Full_File[ Directory_Len - 1 ] = ( char )NULL;
                  strcat( Full_File, Sub_Directory );
                  strcat( Full_File, "]" );
                  if ( File_Len > 0 )
                     strcat( Full_File, File );
	       }
               else
	       { /* [a.] + file --> [a]file */

                  Full_File_Len -= 1;
                  Full_File = ( STRING )Allocate_Memory( Full_File_Len + 1 );
                  strncpy( Full_File, Directory, Directory_Len - 2 );
                  Full_File[ Directory_Len - 2 ] = ( char )NULL;
                  strcat( Full_File, "]" );
                  if ( File_Len > 0 )
                     strcat( Full_File, File );
	       }

/**********************************
* Build_Full_VMS_File_Name page 3 *
**********************************/

	    }
	    else
            { /* Directory = [a] */

               if ( Sub_Directory_Len > 0 )
	       { /* [a] + b + file --> [a.b]file */

                  Full_File_Len += 1;
                  Full_File = ( STRING )Allocate_Memory( Full_File_Len + 1 );
                  strncpy( Full_File, Directory, Directory_Len - 1 );
                  Full_File[ Directory_Len - 1 ] = ( char )NULL;
                  strcat( Full_File, "." );
                  strcat( Full_File, Sub_Directory );
                  strcat( Full_File, "]" );
                  if ( File_Len > 0 )
                     strcat( Full_File, File );
	       }
               else
	       { /* [a] + file --> [a]file */

                  Full_File =
                           ( STRING )Allocate_Memory( Full_File_Len + 1 );
                  strcpy( Full_File, Directory );
                  if ( File_Len > 0 )
                     strcat( Full_File, File );
	       }
	    }
            break;
         case ':':
            if ( Sub_Directory_Len > 0 )
	    { /* a: + b + file --> a:[b]file */

               Full_File_Len += 2;
               Full_File = ( STRING )Allocate_Memory( Full_File_Len + 1 );
               strcpy( Full_File, Directory );
               strcat( Full_File, "[" );
               strcat( Full_File, Sub_Directory );
               strcat( Full_File, "]" );
               if ( File_Len > 0 )
                  strcat( Full_File, File );
	    }
	    else
	    { /* a: file --> a:file */

               Full_File = ( STRING )Allocate_Memory( Full_File_Len + 1 );
               strcpy( Full_File, Directory );
               if ( File_Len > 0 )
                  strcat( Full_File, File );
	    }
            break;
         default :
            if ( Sub_Directory_Len > 0 )
	    { /* a + b + file --> a:[b]file */

               Full_File_Len += 3;
               Full_File = ( STRING )Allocate_Memory( Full_File_Len + 1 );
               strcpy( Full_File, Directory );
               strcat( Full_File, ":[" );
               strcat( Full_File, Sub_Directory );
               strcat( Full_File, "]" );

/**********************************
* Build_Full_VMS_File_Name page 4 *
**********************************/

               if ( File_Len > 0 )
                  strcat( Full_File, File );
	    }
	    else
	    { /* a + file --> a:file */

               Full_File_Len += 1;
               Full_File = ( STRING )Allocate_Memory( Full_File_Len + 1 );
               strcpy( Full_File, Directory );
               strcat( Full_File, ":" );
               if ( File_Len > 0 )
                  strcat( Full_File, File );
	    }
      } /* Process each case with a directory */

   } /* We've got a directory */
   else
   { /* We don't got a directory */

      if ( Sub_Directory_Len > 0 )
      { /* b + file --> [.b]file */

         Full_File_Len += 3;
         Full_File = ( STRING )Allocate_Memory( Full_File_Len + 1 );
         strcpy( Full_File, "[." );
         strcat( Full_File, Sub_Directory );
         strcat( Full_File, "]" );
         if ( File_Len > 0 )
            strcat( Full_File, File );
      }
      else
      { /* file --> file. */

         Full_File = ( STRING )Allocate_Memory( Full_File_Len + 1 );
         if ( File_Len > 0 )
            strcpy( Full_File, File );
         else
            Full_File[ 0 ] = ( char )NULL;
      }

   } /* We don't got a directory */

   return Full_File;
}
/***********************************************
* Build_Full_VMS_File_Name end executable code *
***********************************************/

/******************************************************************************
* Module:                                                                     *
*    CopyRight_File_Exists                                                    *
*                                                                             *
* File:                                                                       *
*    filenams.c                                                               *
*                                                                             *
* Description:                                                                *
*       Returns TRUE if copyright file exists in the given directory. This is *
*       true if either FileNames_in_LowerCase returns true or                 *
*       FileNames_in_UpperCase returns true.                                  *
*                                                                             *
* Return Value:                                                               *
*    BOOL: TRUE if copyright file is found in given directory.                *
*                                                                             *
* Arguments;                                                                  *
*                                                                             *
*    Input Arguments:                                                         *
*       Directory                                                             *
*          STRING, Reference                                                  *
*             Name of directory where we look for the copyright file.         *
*    Input/Output Arguments:                                                  *
*       none                                                                  *
*    Output Arguments:                                                        *
*       none                                                                  *
*                                                                             *
* History:                                                                    *
*    Created    : 15-NOV-93 by J. Doggett,                                    *
*       for the Association of Universities for Research in Astronomy, Inc.   *
*          at the Space Telescope Science Institute,                          *
*       to facilitate the accessing of data from the CD-ROM set of the        *
*          Digitized Sky Survey.                                              *
*    Delivered  : 01-MAR-94 by J. Doggett,                                    *
*       GetImage Version 1.0                                                  *
******************************************************************************/
/*************************************
* CopyRight_File_Exists declarations *
*************************************/
BOOL   CopyRight_File_Exists( Directory )
STRING Directory;
{
/**********************************************
* CopyRight_File_Exists begin executable code *
**********************************************/
   if  ( (int)FileNames_in_LowerCase( Directory )
                         ||
         (int)FileNames_in_UpperCase( Directory ) )
      return TRUE;
   else
      return FALSE;
}
/********************************************
* CopyRight_File_Exists end executable code *
********************************************/

/******************************************************************************
* Module:                                                                     *
*    FileNames_in_LowerCase                                                   *
*                                                                             *
* File:                                                                       *
*    filenams.c                                                               *
*                                                                             *
* Description:                                                                *
*       Returns TRUE if copyright file exists in given directory with lower   *
*       case filename, else it returns FALSE.                                 *
*                                                                             *
* Return Value:                                                               *
*    BOOL: TRUE if CD-ROM filenames are lowercase, otherwise, FALSE.          *
*                                                                             *
* Arguments;                                                                  *
*                                                                             *
*    Input Arguments:                                                         *
*       Directory                                                             *
*          STRING, Reference                                                  *
*             Name of directory where we look for the copyright file.         *
*    Input/Output Arguments:                                                  *
*       none                                                                  *
*    Output Arguments:                                                        *
*       none                                                                  *
*                                                                             *
* History:                                                                    *
*    Created    : 15-NOV-93 by J. Doggett,                                    *
*       for the Association of Universities for Research in Astronomy, Inc.   *
*          at the Space Telescope Science Institute,                          *
*       to facilitate the accessing of data from the CD-ROM set of the        *
*          Digitized Sky Survey.                                              *
*    Delivered  : 01-MAR-94 by J. Doggett,                                    *
*       GetImage Version 1.0                                                  *
******************************************************************************/
/**************************************
* FileNames_in_LowerCase declarations *
**************************************/
BOOL   FileNames_in_LowerCase( Directory )
STRING Directory;
{
   STRING CopyRight_FileName;

/***********************************************
* FileNames_in_LowerCase begin executable code *
***********************************************/
   CopyRight_FileName = Build_Full_File_Name( Directory, "", "copyrght.;1" );
   if ( access( CopyRight_FileName, 0 ) == 0)
   {
      free( CopyRight_FileName );
      return TRUE;
   }

   CopyRight_FileName = Build_Full_File_Name( Directory, "", "copyrght;1" );
   if ( access( CopyRight_FileName, 0 ) == 0)
   {
      free( CopyRight_FileName );
      return TRUE;
   }

   CopyRight_FileName = Build_Full_File_Name( Directory, "", "copyrght." );
   if ( access( CopyRight_FileName, 0 ) == 0)
   {
      free( CopyRight_FileName );
      return TRUE;

/********************************
* FileNames_in_LowerCase page 2 *
********************************/

   }

   CopyRight_FileName = Build_Full_File_Name( Directory, "", "copyrght" );
   if ( access( CopyRight_FileName, 0 ) == 0)
   {
      free( CopyRight_FileName );
      return TRUE;
   }

   free( CopyRight_FileName );
   return FALSE;
}
/*********************************************
* FileNames_in_LowerCase end executable code *
*********************************************/

/******************************************************************************
* Module:                                                                     *
*    FileNames_in_UpperCase                                                   *
*                                                                             *
* File:                                                                       *
*    filenams.c                                                               *
*                                                                             *
* Description:                                                                *
*       Returns TRUE if copyright file exists in given directory with upper   *
*       case filename, else it returns FALSE.                                 *
*                                                                             *
* Return Value:                                                               *
*    BOOL: TRUE if CD-ROM filenames are uppercase, otherwise, FALSE.          *
*                                                                             *
* Arguments;                                                                  *
*                                                                             *
*    Input Arguments:                                                         *
*       Directory                                                             *
*          STRING, Reference                                                  *
*             Name of directory where we look for the copyright file.         *
*    Input/Output Arguments:                                                  *
*       none                                                                  *
*    Output Arguments:                                                        *
*       none                                                                  *
*                                                                             *
* History:                                                                    *
*    Created    : 15-NOV-93 by J. Doggett,                                    *
*       for the Association of Universities for Research in Astronomy, Inc.   *
*          at the Space Telescope Science Institute,                          *
*       to facilitate the accessing of data from the CD-ROM set of the        *
*          Digitized Sky Survey.                                              *
*    Delivered  : 01-MAR-94 by J. Doggett,                                    *
*       GetImage Version 1.0                                                  *
******************************************************************************/
/**************************************
* FileNames_in_UpperCase declarations *
**************************************/
BOOL   FileNames_in_UpperCase( Directory )
STRING Directory;
{
   STRING CopyRight_FileName;

/***********************************************
* FileNames_in_UpperCase begin executable code *
***********************************************/
   CopyRight_FileName = Build_Full_File_Name( Directory, "", "COPYRGHT.;1" );
   if ( access( CopyRight_FileName, 0 ) == 0)
   {
      free( CopyRight_FileName );
      return TRUE;
   }

   CopyRight_FileName = Build_Full_File_Name( Directory, "", "COPYRGHT;1" );
   if ( access( CopyRight_FileName, 0 ) == 0)
   {
      free( CopyRight_FileName );
      return TRUE;
   }

   CopyRight_FileName = Build_Full_File_Name( Directory, "", "COPYRGHT." );
   if ( access( CopyRight_FileName, 0 ) == 0)
   {
      free( CopyRight_FileName );
      return TRUE;

/********************************
* FileNames_in_UpperCase page 2 *
********************************/
   }

   CopyRight_FileName = Build_Full_File_Name( Directory, "", "COPYRGHT" );
   if ( access( CopyRight_FileName, 0 ) == 0)
   {
      free( CopyRight_FileName );
      return TRUE;
   }

   free( CopyRight_FileName );
   return FALSE;
}
/*********************************************
* FileNames_in_UpperCase end executable code *
*********************************************/

/******************************************************************************
* Module:                                                                     *
*    FileNames_have_Version                                                   *
*                                                                             *
* File:                                                                       *
*    filenams.c                                                               *
*                                                                             *
* Description:                                                                *
*       Returns TRUE if name of copyright file in given directory has a       *
*       version number, ie, a trailing semicolon followed by a 1.             *
*                                                                             *
* Return Value:                                                               *
*    BOOL: TRUE if CD-ROM file names have the file version                    *
*                                                                             *
* Arguments;                                                                  *
*                                                                             *
*    Input Arguments:                                                         *
*       Directory                                                             *
*          STRING, Reference                                                  *
*             Name of directory where we look for the copyright file.         *
*    Input/Output Arguments:                                                  *
*       none                                                                  *
*    Output Arguments:                                                        *
*       none                                                                  *
*                                                                             *
* History:                                                                    *
*    Created    : 15-NOV-93 by J. Doggett,                                    *
*       for the Association of Universities for Research in Astronomy, Inc.   *
*          at the Space Telescope Science Institute,                          *
*       to facilitate the accessing of data from the CD-ROM set of the        *
*          Digitized Sky Survey.                                              *
*    Delivered  : 01-MAR-94 by J. Doggett,                                    *
*       GetImage Version 1.0                                                  *
******************************************************************************/
/**************************************
* FileNames_have_Version declarations *
**************************************/
BOOL   FileNames_have_Version( Directory )
STRING Directory;
{
   STRING CopyRight_FileName;

/***********************************************
* FileNames_have_Version begin executable code *
***********************************************/
   CopyRight_FileName = Build_Full_File_Name( Directory, "", "COPYRGHT.;1" );
   if ( access( CopyRight_FileName, 0 ) == 0)
   {
      free( CopyRight_FileName );
      return TRUE;
   }

   CopyRight_FileName = Build_Full_File_Name( Directory, "", "COPYRGHT;1" );
   if ( access( CopyRight_FileName, 0 ) == 0)
   {
      free( CopyRight_FileName );
      return TRUE;
   }

   CopyRight_FileName = Build_Full_File_Name( Directory, "", "copyrght.;1" );
   if ( access( CopyRight_FileName, 0 ) == 0)
   {
      free( CopyRight_FileName );
      return TRUE;

/*********************************
* FileNames_have_Version  page 2 *
*********************************/

   }

   CopyRight_FileName = Build_Full_File_Name( Directory, "", "copyrght;1" );
   if ( access( CopyRight_FileName, 0 ) == 0)
   {
      free( CopyRight_FileName );
      return TRUE;
   }

   free( CopyRight_FileName );
   return FALSE;
}
/*********************************************
* FileNames_have_Version end executable code *
*********************************************/

/******************************************************************************
* Module:                                                                     *
*    FileNames_Trailing_Period                                                *
*                                                                             *
* File:                                                                       *
*    filenams.c                                                               *
*                                                                             *
* Description:                                                                *
*       Returns TRUE if copyright file exists in the given directory with a   *
*       trailing period before the trailing semicolon (if there is one).      *
*       This indicates that filenames without extensios keep the period       *
*       separator.                                                            *
*                                                                             *
* Return Value:                                                               *
*    BOOL: TRUE if CD-ROM file names have trailing periods.                   *
*                                                                             *
* Arguments;                                                                  *
*                                                                             *
*    Input Arguments:                                                         *
*       Directory                                                             *
*          STRING, Reference                                                  *
*             Name of directory where we look for the copyright file.         *
*    Input/Output Arguments:                                                  *
*       none                                                                  *
*    Output Arguments:                                                        *
*       none                                                                  *
*                                                                             *
* History:                                                                    *
*    Created    : 15-NOV-93 by J. Doggett,                                    *
*       for the Association of Universities for Research in Astronomy, Inc.   *
*          at the Space Telescope Science Institute,                          *
*       to facilitate the accessing of data from the CD-ROM set of the        *
*          Digitized Sky Survey.                                              *
*    Delivered  : 01-MAR-94 by J. Doggett,                                    *
*       GetImage Version 1.0                                                  *
******************************************************************************/
/*****************************************
* FileNames_Trailing_Period declarations *
*****************************************/
BOOL   FileNames_Trailing_Period( Directory )
STRING Directory;
{
   STRING CopyRight_FileName;

/**************************************************
* FileNames_Trailing_Period begin executable code *
**************************************************/
   CopyRight_FileName = Build_Full_File_Name( Directory, "", "COPYRGHT.;1" );
   if ( access( CopyRight_FileName, 0 ) == 0)
   {
      free( CopyRight_FileName );
      return TRUE;
   }

   CopyRight_FileName = Build_Full_File_Name( Directory, "", "COPYRGHT." );
   if ( access( CopyRight_FileName, 0 ) == 0)
   {
      free( CopyRight_FileName );
      return TRUE;
   }

   CopyRight_FileName = Build_Full_File_Name( Directory, "", "copyrght.;1" );
   if ( access( CopyRight_FileName, 0 ) == 0)
   {

/************************************
* FileNames_Trailing_Period page 2 *
************************************/
      free( CopyRight_FileName );
      return TRUE;
   }

   CopyRight_FileName = Build_Full_File_Name( Directory, "", "copyrght." );
   if ( access( CopyRight_FileName, 0 ) == 0)
   {
      free( CopyRight_FileName );
      return TRUE;
   }

   free( CopyRight_FileName );
   return FALSE;
}
/************************************************
* FileNames_Trailing_Period end executable code *
************************************************/

/******************************************************************************
* Module:                                                                     *
*    Set_FileNames_Case                                                       *
*                                                                             *
* File:                                                                       *
*    filenams.c                                                               *
*                                                                             *
* Description:                                                                *
*       Set the case of a filename according to the case of the copyright     *
*       file in given directory. Returns TRUE if action is successful.        *
*       Othewise, FALSE.                                                      *
*                                                                             *
* Return Value:                                                               *
*    BOOL: TRUE if the case is set successfully. Otherwise, FALSE.            *
*                                                                             *
* Arguments;                                                                  *
*                                                                             *
*    Input Arguments:                                                         *
*       Directory                                                             *
*          STRING, Reference                                                  *
*             Name of directory where we look for the copyright file.         *
*       FileName                                                              *
*          STRING, Reference                                                  *
*             String whose case we're setting.                                *
*    Input/Output Arguments:                                                  *
*       none                                                                  *
*    Output Arguments:                                                        *
*       none                                                                  *
*                                                                             *
* History:                                                                    *
*    Created    : 18-NOV-93 by J. Doggett,                                    *
*       for the Association of Universities for Research in Astronomy, Inc.   *
*          at the Space Telescope Science Institute,                          *
*       to facilitate the accessing of data from the CD-ROM set of the        *
*          Digitized Sky Survey.                                              *
*    Delivered  : 01-MAR-94 by J. Doggett,                                    *
*       GetImage Version 1.0                                                  *
******************************************************************************/
/**********************************
* Set_FileNames_Case declarations *
**********************************/
BOOL   Set_FileNames_Case(Directory, FileName)
STRING Directory;
STRING FileName;
{
/*******************************************
* Set_FileNames_Case begin executable code *
*******************************************/
   if (!CopyRight_File_Exists(Directory))
      return FALSE;

   if (FileNames_in_LowerCase(Directory))
      Convert_String_to_Lower_Case(FileName);
   else
      Convert_String_to_Upper_Case(FileName);

   return TRUE;
}
/*****************************************
* Set_FileNames_Case end executable code *
*****************************************/

/******************************************************************************
* Module:                                                                     *
*    Set_FileNames_Version                                                    *
*                                                                             *
* File:                                                                       *
*    filenams.c                                                               *
*                                                                             *
* Description:                                                                *
*       Add the version, semicolon followed by a 1, to a filename if the      *
*       copyright file in given directory has the version. If no version is   *
*       to be added, then the input string is returned.                       *
*                                                                             *
* Return Value:                                                               *
*    STRING: Resulting string, or NULL if there's an error.                   *
*                                                                             *
* Arguments;                                                                  *
*                                                                             *
*    Input Arguments:                                                         *
*       Directory                                                             *
*          STRING, Reference                                                  *
*             Name of directory where we look for the copyright file.         *
*       FileName                                                              *
*          STRING, Reference                                                  *
*             String whose case we're setting.                                *
*    Input/Output Arguments:                                                  *
*       none                                                                  *
*    Output Arguments:                                                        *
*       none                                                                  *
*                                                                             *
* History:                                                                    *
*    Created    : 18-NOV-93 by J. Doggett,                                    *
*       for the Association of Universities for Research in Astronomy, Inc.   *
*          at the Space Telescope Science Institute,                          *
*       to facilitate the accessing of data from the CD-ROM set of the        *
*          Digitized Sky Survey.                                              *
*    Delivered  : 01-MAR-94 by J. Doggett,                                    *
*       GetImage Version 1.0                                                  *
******************************************************************************/
/*************************************
* Set_FileNames_Version declarations *
*************************************/
STRING Set_FileNames_Version(Directory, FileName)
STRING Directory;
STRING FileName;
{
   STRING NewFileName; /* Filename after Version has been appropriately added

/**********************************************
* Set_FileNames_Version begin executable code *
**********************************************/
   if (!CopyRight_File_Exists(Directory))
      return (STRING)NULL;

   if (FileNames_have_Version(Directory))  {
      NewFileName = (STRING) Allocate_Memory(strlen(FileName) + 2);
      strcpy(NewFileName, FileName);
      strcat(NewFileName, ";1");
   }
   else
      NewFileName = FileName;

   return NewFileName;
}


/*******************************
* Set_FileNames_Version page 2 *
*******************************/

/********************************************
* Set_FileNames_Version end executable code *
********************************************/
